MAIN_DIR=~/oat_aphid/
RAW_READS_DIR=$MAIN_DIR/X201SC23073947-Z01-F001/01.RawData
TRIM_DIR=$MAIN_DIR/reads_trim
SRR_DIR=$MAIN_DIR/SRR3203855
MAP_DIR=$MAIN_DIR/map

CORES=20

SAMPLES=$MAIN_DIR/samples.txt
GENOME=$MAIN_DIR/refs/Rpadi_GCA_020882245.1.fna
ANNOTS=$MAIN_DIR/refs/Rpadi_GCA_020882245.1_annots.gff

# Mapping directory
mkdir -v $MAP_DIR
cd $MAP_DIR

# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
####   MAPPING WGS READS   ####
# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

# Build reference
# bowtie2-build \
# -f \
# --threads $CORES \
# $GENOME \
# $GENOME


# START LOOP
for i in $(cat $SAMPLES)
do

# Map
bowtie2 \
-x $GENOME \
-p $CORES \
-1 $TRIM_DIR/${i}_trim_F.fq.gz \
-2 $TRIM_DIR/${i}_trim_R.fq.gz \
--very-sensitive \
--rg-id ${i} \
--rg SM:${i} \
> ${i}_map.sam 2> ${i}_map.log

# Sort
samtools view -b -h -F4 -q30 -@$CORES -T $GENOME ${i}_map.sam |
samtools sort -@$CORES - > ${i}_map_sort.bam

# Remove unsorted original
rm ${i}_map.sam

# Deduplicate
samtools sort -n --reference $GENOME -@$CORES ${i}_map_sort.bam |
samtools fixmate -m --reference $GENOME -@$CORES - - |
samtools sort --reference $GENOME -@$CORES - |
samtools markdup -r --reference $GENOME -@$CORES - ${i}_map_sort_nodup.bam

# Index
samtools index -@$CORES ${i}_map_sort.bam
samtools index -@$CORES ${i}_map_sort_nodup.bam
done
# END LOOP

# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
####   MAPPING RNA-SEQ READS   ####
# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

# Prepare the annotations
conda activate gffread_env

gffread $ANNOTS --gtf > $MAIN_DIR/refs/Rpadi_GCA_020882245.1_annots.gtf

conda deactivate

# RNA stuff
conda activate rna_seq_env

# Build reference with splice sites

ANNOTS2=$MAIN_DIR/refs/Rpadi_GCA_020882245.1_annots.gtf

hisat2_extract_splice_sites.py ${ANNOTS2} > $MAIN_DIR/refs/Rpadi_GCA_020882245.1_splice_sites.bed
hisat2_extract_exons.py ${ANNOTS2} > $MAIN_DIR/refs/Rpadi_GCA_020882245.1_exons.bed

hisat2-build \
-p $CORES \
--ss $MAIN_DIR/refs/Rpadi_GCA_020882245.1_splice_sites.bed \
--exon $MAIN_DIR/refs/Rpadi_GCA_020882245.1_exons.bed \
$GENOME \
$GENOME

# Map
hisat2 \
-x $GENOME \
-p $CORES \
-U $TRIM_DIR/OAT_SRR3203855_trim_F.fq.gz \
--very-sensitive \
--rg-id OAT_SRR3203855 \
--rg SM:OAT_SRR3203855 \
> OAT_SRR3203855_map.sam 2> OAT_SRR3203855_map.log

# Sort
samtools view -b -h -F4 -q30 -@$CORES -T $GENOME OAT_SRR3203855_map.sam |
samtools sort -@$CORES - > OAT_SRR3203855_map_sort.bam

# Remove unsorted original
rm OAT_SRR3203855_map.sam

# Deduplicate
samtools sort -n --reference $GENOME -@$CORES OAT_SRR3203855_map_sort.bam |
samtools fixmate -m --reference $GENOME -@$CORES - - |
samtools sort --reference $GENOME -@$CORES - |
samtools markdup -r --reference $GENOME -@$CORES - OAT_SRR3203855_map_sort_nodup.bam

# Index
samtools index -@$CORES OAT_SRR3203855_map_sort.bam
samtools index -@$CORES OAT_SRR3203855_map_sort_nodup.bam