MAIN_DIR=~/oat_aphid/
RAW_READS_DIR=$MAIN_DIR/X201SC23073947-Z01-F001/01.RawData
MAP_DIR=$MAIN_DIR/map
VAR_DIR=$MAIN_DIR/vars

CORES=20

SAMPLES=$MAIN_DIR/samples.txt
GENOME=$MAIN_DIR/refs/Rpadi_GCA_020882245.1.fna

source activate freebayes_env

# Variant directory
mkdir -v $VAR_DIR
cd $VAR_DIR

# List of BAMs
ls $MAP_DIR/*_map_sort_nodup.bam > bamlist

# Subset the genome into 1 Mb regions
fasta_generate_regions.py $GENOME 10000000 > regions.bed

# Iterate over the regions, and call variants
cat regions.bed | parallel -j $CORES "
# Call variants per region
freebayes \
-L bamlist \
-f $GENOME \
-r {} \
--min-mapping-quality 20 \
--min-alternate-count 2 \
--pooled-continuous > vars.tmp.{}.vcf

# Zip
bgzip vars.tmp.{}.vcf

# Index
bcftools index vars.tmp.{}.vcf.gz
"

ls vars.tmp*.vcf.gz > vcf_files

bcftools concat -aD -f vcf_files --threads $CORES > vars_raw.vcf

# Clean up
mkdir -v tmp_vcf_files
mv vars.tmp* tmp_vcf_files

# Biallelic variants
vcftools \
--vcf vars_raw.vcf \
--recode \
--recode-INFO-all \
--min-alleles 2 \
--max-alleles 2 \
--minQ 20 \
--out vars_bi_minq

mv vars_bi_minq.recode.vcf vars_bi_minq.vcf

vcftools \
--vcf vars_bi_minq.vcf \
--recode \
--recode-INFO-all \
--minDP 20 \
--max-missing 1 \
--mac 2 \
--out vars_bi_minq_mindp_miss_mac_all

mv vars_bi_minq_mindp_miss_mac_all.recode.vcf vars_bi_minq_mindp_miss_mac_all.vcf

vcftools \
--vcf vars_bi_minq.vcf \
--remove-indv OAT_SRR3203855 \
--recode \
--recode-INFO-all \
--minDP 20 \
--max-missing 1 \
--mac 2 \
--out vars_bi_minq_mindp_miss_mac_noSRR

mv vars_bi_minq_mindp_miss_mac_noSRR.recode.vcf vars_bi_minq_mindp_miss_mac_noSRR.vcf

# Get the SNPs only
bcftools filter -e "TYPE!='snp'" \
vars_bi_minq_mindp_miss_mac_all.vcf > vars_bi_minq_mindp_miss_mac_all_snp.vcf

bcftools filter -e "TYPE!='snp'" \
vars_bi_minq_mindp_miss_mac_noSRR.vcf > vars_bi_minq_mindp_miss_mac_noSRR_snp.vcf

